#ifndef FILTERLISTBYDIALOG_H
#define FILTERLISTBYDIALOG_H

#include <QDialog>

namespace Ui {
    class FilterListByDialog;
}

class FilterListByDialog : public QDialog
{
    Q_OBJECT



public:

    explicit FilterListByDialog(int type, QStringList fillingList, QWidget *parent = 0);
    ~FilterListByDialog();



private:
    Ui::FilterListByDialog *ui;
    int type;

signals:
    void choicePicked(int type, QString filter, int sortType);

private slots:
    void on_okButton_clicked();
};

#endif // FILTERLISTBYDIALOG_H
